TabControllerWithKeepAliveState<P extends BasePage<BaseController<BaseModel>, BaseModel>, T extends BaseController<BaseModel>> class

TickerProviderStateMixin 和 AutomaticKeepAliveClientMixin

Inheritance
Mixed-in types

Properties

context → BuildContext
The location in the tree where this widget builds.
no setterinherited
currentTag ↔ String?
getter/setter pairinherited
hashCode → int
The hash code for this object.
no setterinherited
mounted → bool
Whether this State object is currently in a tree.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
wantKeepAlive → bool
Whether the current instance should be kept alive.
no setteroverride
widget → P
The current configuration.
no setterinherited

Methods

activate() → void
Called when this object is reinserted into the tree after having been removed via deactivate.
inherited
build(BuildContext context) → Widget
Describes the part of the user interface represented by this widget.
override
createTicker(TickerCallback onTick) → Ticker
Creates a ticker with the given callback.
inherited
deactivate() → void
Called when this object is removed from the tree.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
didChangeDependencies() → void
Called when a dependency of this State object changes.
inherited
didPop() → void
Called when the current route has been popped off.
inherited
didPopNext() → void
Called when the top route has been popped off, and the current route shows up.
inherited
didPush() → void
Called when the current route has been pushed.
inherited
didPushNext() → void
Called when a new route has been pushed on top of this route, temporarily obscuring it.
inherited
didUpdateWidget(covariant P oldWidget) → void
Called whenever the widget configuration changes.
inherited
dispose() → void
Called when this object is removed from the tree permanently.
inherited
initState() → void
Called when this object is inserted into the tree.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
reassemble() → void
Called whenever the application is reassembled during debugging, for example during hot reload.
inherited
setState(VoidCallback fn) → void
Notify the framework that the internal state of this object has changed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringShort() → String
A brief description of this object, usually just the runtimeType and the hashCode.
inherited
updateKeepAlive() → void
Ensures that any AutomaticKeepAlive ancestors are in a good state, by firing a KeepAliveNotification or triggering the KeepAliveHandle as appropriate.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited