PageInterface class abstract

Implementers

Constructors

PageInterface()

Properties

appBar → Widget?
no setter
appBarHeight → double
no setter
backgroundColor → Color
no setter
body → Widget
no setter
bottomBar → Widget?
no setter
enableWillPop → bool
no setter
extendBody → bool
no setter
extendBodyBehindAppBar → bool
no setter
hashCode → int
The hash code for this object.
no setterinherited
resizeToAvoidBottomInset → bool
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
scaffold → Widget
no setter
statusBody → Widget
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited