ResponsiveInterface class abstract

Constructors

ResponsiveInterface()

Properties

backgroundColor → Color?
no setter
defaultBody → Widget
no setter
desktopBody → Widget?
no setter
hashCode → int
The hash code for this object.
no setterinherited
mobileBody → Widget?
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
tabletBody → Widget?
no setter
watchBody → Widget?
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited