BaseStateStatusPage<T extends BaseStatusController<BaseModel>, M extends BaseModel> class abstract

Inheritance

Constructors

BaseStateStatusPage({Key? key})

Properties

appBar → Widget?
no setterinherited
appBarHeight → double
no setterinherited
backgroundColor → Color
no setterinherited
binding → T
no setteroverride
body → Widget
no setterinherited
bottomBar → Widget?
no setterinherited
controller → T
no setteroverride
empty → Widget
no setterinherited
enableGetxMvc → bool
no setteroverride
enableWillPop → bool
no setterinherited
error → Widget
no setterinherited
extendBody → bool
no setterinherited
extendBodyBehindAppBar → bool
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
initController ↔ T
latefinal
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
loading → Widget
no setterinherited
model → M
no setterinherited
permanentController → bool
no setterinherited
resizeToAvoidBottomInset → bool
no setterinherited
reuseController → bool
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
scaffold → Widget
no setterinherited
statusBody → Widget
no setterinherited
tag → String?
no setterinherited
tagRepeat → String?
no setterinherited
tagSymbol → String
no setterinherited

Methods

build(BuildContext context) → Widget
override
createElement() → StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() → State<BasePage<BaseController<BaseModel>, BaseModel>>
Creates the mutable state for this widget at a given location in the tree.
inherited
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
init() → void
inherited
initRepeatTag(String? tag) → void
满足以下条件时使用,为了防止热重载而导致GlobalKey被重复使用: 1.页面需要重复跳转 且reuseController为false 2.页面中引用了controller或者model中声明且已经创建的GlobalKey对象
inherited
initTabController(TickerProvider vsync) → void
仅在 createState 为 TabControllerState 时使用
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited